@@ -32,7 +32,6 @@
 #include "flatpak-session-helper.h"
 #include "flatpak-utils-base-private.h"
 
-static GStrv original_environ = NULL;
 static char *monitor_dir;
 static char *p11_kit_server_socket_path;
 static int p11_kit_server_pid = 0;
@@ -311,7 +310,7 @@ handle_host_command (FlatpakDevelopment    *object,
       env = g_strdupv (empty);
     }
   else
-    env = g_strdupv (original_environ);
+    env = g_get_environ ();
 
   n_envs = g_variant_n_children (arg_envs);
   for (i = 0; i < n_envs; i++)
@@ -681,7 +680,7 @@ message_handler (const gchar   *log_domain,
                  gpointer       user_data)
 {
   /* Make this look like normal console output */
-  if (log_level & (G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO))
+  if (log_level & G_LOG_LEVEL_DEBUG)
     g_printerr ("F: %s\n", message);
   else
     g_printerr ("%s: %s\n", g_get_prgname (), message);
@@ -784,10 +783,6 @@ main (int    argc,
                          m_localtime = NULL;
   struct sigaction action;
 
-  /* Save the enviroment before changing anything, so that subprocesses
-   * can get the unchanged version */
-  original_environ = g_get_environ ();
-
   atexit (do_atexit);
 
   memset (&action, 0, sizeof (struct sigaction));
@@ -831,7 +826,7 @@ main (int    argc,
     }
 
   if (verbose)
-    g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO, message_handler, NULL);
+    g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, message_handler, NULL);
 
   client_pid_data_hash = g_hash_table_new_full (NULL, NULL, NULL, (GDestroyNotify) pid_data_free);
 
@@ -885,6 +880,5 @@ main (int    argc,
 
   g_bus_unown_name (owner_id);
 
-  g_strfreev (original_environ);
   return 0;
 }
